syntropy.knn package
====================

.. automodule:: syntropy.knn
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

syntropy.knn.multivariate\_mi module
------------------------------------

.. automodule:: syntropy.knn.multivariate_mi
   :members:
   :show-inheritance:
   :undoc-members:

syntropy.knn.shannon module
---------------------------

.. automodule:: syntropy.knn.shannon
   :members:
   :show-inheritance:
   :undoc-members:

syntropy.knn.utils module
-------------------------

.. automodule:: syntropy.knn.utils
   :members:
   :show-inheritance:
   :undoc-members:
